==> hollow-cli-2.1.2.tgz: package/esm/mwBuild.js <==
import * as tslib_1 from "tslib";
import path from 'path';
import { checkWebpackConfig, getNodeVersion, getBuildSourceMap } from './util';
import merge from 'webpack-merge';
export default function mwBuild(context, next) {
  return tslib_1.__awaiter(this, void 0, void 0, function () {
    var _a, cwd, devtool, rules, ENV, packageMap, outputPath, publicPath, hash, output, _b, unknownContextCritical, alias, config, webpackConfig;

    return tslib_1.__generator(this, function (_c) {
      context.output = {};
      context.webpackConfig = {};
      next();
      cwd = context.cwd, devtool = context.devtool, rules = context.rules, ENV = context.ENV, packageMap = context.packageMap, outputPath = context.outputPath, publicPath = context.publicPath, hash = context.hash, output = context.output, _b = context.unknownContextCritical, unknownContextCritical = _b === void 0 ? false : _b, alias = context.alias;
      config = tslib_1.__assign({
        cache: true,
        entry: context.entry || packageMap.entry,
        resolve: tslib_1.__assign({
          modules: ['node_modules'],
          extensions: ['.web.tsx', '.web.ts', '.web.jsx', '.web.js', '.ts', '.tsx', '.js', '.jsx', '.json', '.json5', '.worker.js', '.worker.jsx', '.gql', '.graphql', '.mjs'],
          alias: tslib_1.__assign((_a = {}, _a['@babel/runtime'] = path.dirname(require.resolve('@babel/runtime/package.json')), _a['tslib'] = path.dirname(require.resolve('tslib/package.json')), _a), alias)
        }, context.resolve),
        output: tslib_1.__assign({
          filename: hash ? '[name]-[contenthash].js' : '[name].js',
          chunkFilename: hash ? '[name].chunk-[contenthash].js' : '[name].chunk.js',
          globalObject: 'this',
          pathinfo: false,
          publicPath: context.ASSET_PATH
        }, output),
        context: context.context || cwd,
        externals: context.externals,
        node: getNodeVersion(packageMap),
        devtool: getBuildSourceMap(devtool, ENV),
        module: {
          strictExportPresence: false,
          noParse: [/moment$/],
          rules: rules,
          unknownContextCritical: unknownContextCritical
        },
        plugins: context.plugins,
        mode: 'none',
        performance: false
      }, context.webpackConfig);
      webpackConfig = context.webpackConfig = merge(context.webpackConfig, config);

      if (outputPath) {
        webpackConfig.output.path = path.join(cwd, outputPath);
      }

      if (publicPath) {
        webpackConfig.output.publicPath = publicPath;
      }

      checkWebpackConfig(webpackConfig);
      return [2];
    });
  });
}

==> hollow-cli-2.1.12.tgz: package/esm/mwBuild.js <==
import * as tslib_1 from "tslib";
import path from 'path';
import { checkWebpackConfig, getNodeVersion, getBuildSourceMap } from './util';
import merge from 'webpack-merge';
export default function mwBuild(context, next) {
  return tslib_1.__awaiter(this, void 0, void 0, function () {
    var _a, cwd, devtool, rules, ENV, packageMap, outputPath, publicPath, hash, output, _b, unknownContextCritical, alias, config, webpackConfig;

    return tslib_1.__generator(this, function (_c) {
      context.output = {};
      context.webpackConfig = {};
      next();
      cwd = context.cwd, devtool = context.devtool, rules = context.rules, ENV = context.ENV, packageMap = context.packageMap, outputPath = context.outputPath, publicPath = context.publicPath, hash = context.hash, output = context.output, _b = context.unknownContextCritical, unknownContextCritical = _b === void 0 ? false : _b, alias = context.alias;
      config = tslib_1.__assign({
        cache: true,
        entry: context.entry || packageMap.entry,
        resolve: tslib_1.__assign({
          modules: ['node_modules'],
          extensions: ['.web.tsx', '.web.ts', '.web.jsx', '.web.js', '.ts', '.tsx', '.js', '.jsx', '.json', '.json5', '.worker.js', '.worker.jsx', '.gql', '.graphql', '.mjs'],
          alias: tslib_1.__assign((_a = {}, _a['@babel/runtime'] = path.dirname(require.resolve('@babel/runtime/package.json')), _a['react'] = path.dirname(require.resolve('react/package.json')), _a['react-dom'] = path.dirname(require.resolve('@hot-loader/react-dom/package.json')), _a['react-hot-loader'] = path.dirname(require.resolve('react-hot-loader/package.json')), _a['babel-core'] = path.dirname(require.resolve('babel-core/package.json')), _a['tslib'] = path.dirname(require.resolve('tslib/package.json')), _a), alias)
        }, context.resolve),
        output: tslib_1.__assign({
          filename: hash ? '[name]-[contenthash].js' : '[name].js',
          chunkFilename: hash ? '[name].chunk-[contenthash].js' : '[name].chunk.js',
          globalObject: 'this',
          pathinfo: false,
          publicPath: context.ASSET_PATH
        }, output),
        context: context.context || cwd,
        externals: context.externals,
        node: getNodeVersion(packageMap),
        devtool: getBuildSourceMap(devtool, ENV),
        module: {
          strictExportPresence: false,
          noParse: [/moment$/],
          rules: rules,
          unknownContextCritical: unknownContextCritical
        },
        plugins: context.plugins,
        mode: 'none',
        performance: false
      }, context.webpackConfig);
      webpackConfig = context.webpackConfig = merge(context.webpackConfig, config);

      if (outputPath) {
        webpackConfig.output.path = path.join(cwd, outputPath);
      }

      if (publicPath) {
        webpackConfig.output.publicPath = publicPath;
      }

      checkWebpackConfig(webpackConfig);
      return [2];
    });
  });
}
